@@ -12,19 +12,18 @@ use File::Temp;
 
 # The EXLOCK is for BSD-based systems.
 
-my($directory)   = File::Temp::newdir('temp.XXXX', CLEANUP => 1, EXLOCK => 0, TMPDIR => 1);
-my($data_source) = 'dbi:SQLite:dbname=' . File::Spec -> catdir($directory, 'sessions.sqlite');
-my($file_name)   = File::Temp -> new(EXLOCK => 0);
-my($type)        = 'driver:File;id:AutoIncrement;serialize:DataDumper'; # Case-sensitive.
+my($directory) = File::Temp::newdir('temp.XXXX', CLEANUP => 1, EXLOCK => 0, TMPDIR => 1);
+my($file_name) = 'autoinc.session.dat';
+my($id_file)   = File::Spec -> catfile($directory, $file_name);
+my($type)      = 'driver:File;id:AutoIncrement;serialize:DataDumper'; # Case-sensitive.
 
 my($id);
 
 {
 my($session) = Data::Session -> new
 (
-	data_source => $data_source,
 	id_base     => 99,
-	id_file     => $file_name,
+	id_file     => $id_file,
 	id_step     => 2,
 	type        => $type,
 ) || die $Data::Session::errstr;
@@ -33,18 +32,18 @@ $id = $session -> id;
 
 $session -> param(a_key => 'a_value');
 
-print "Id: $id. Save a_key: a_value. \n";
+print "Id: $id. Save: a_key => a_value. \n";
 }
 
 {
 my($session) = Data::Session -> new
 (
-	data_source => $data_source,
-	id          => $id,
-	type        => $type,
+	id      => $id,
+	id_file => $id_file,
+	type    => $type,
 ) || die $Data::Session::errstr;
 
-print "Id: $id. Recover a_key: ", $session -> param('a_key'), ". \n";
+print "Id: $id. Recover: a_key => ", $session -> param('a_key'), ". \n";
 
 $session -> delete;
 }
